==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE31S.sql <==
/****************************************************************************/
/* GE31 ( 定型文ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2017/01/05 15:19:02                                            */
/****************************************************************************/

CREATE TABLE GE31 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , PTN_ID       VARCHAR (  20 )                 NOT NULL                                                /*  20 定型文ID     */
 , FROM_ID      VARCHAR (  50 )                                                                         /*  30 送信者ID     */
 , TO_ID        TEXT                                                                                    /*  40 宛先(TO)     */
 , CC_ID        TEXT                                                                                    /*  50 宛先(CC)     */
 , BCC_ID       TEXT                                                                                    /*  60 宛先(BCC)    */
 , TITLE        VARCHAR ( 300 )                 NOT NULL                                                /*  70 ﾀｲﾄﾙ         */
 , CONTENTS     TEXT                                                                                    /*  80 内容         */
 , JOKEN        VARCHAR (  20 )                                                                         /*  85 振分条件     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);

==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE31S.sql <==
/****************************************************************************/
/* GE31 ( 定型文ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE31 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , PTN_ID       VARCHAR (  20 )                 NOT NULL                                                /*  20 定型文ID     */
 , FROM_ID      VARCHAR (  50 )                                                                         /*  30 送信者ID     */
 , TO_ID        TEXT                                                                                    /*  40 宛先(TO)     */
 , CC_ID        TEXT                                                                                    /*  50 宛先(CC)     */
 , BCC_ID       TEXT                                                                                    /*  60 宛先(BCC)    */
 , TITLE        VARCHAR ( 300 )                 NOT NULL                                                /*  70 ﾀｲﾄﾙ         */
 , CONTENTS     TEXT                                                                                    /*  80 内容         */
 , JOKEN        VARCHAR (  20 )                                                                         /*  85 振分条件     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);
